import pyvisa

visa_agilent = 'TCPIP::192.168.1.11::INSTR'
visa_grzegorza = 'TCPIP::192.168.100.76::INSTR'
N9010A = None

def ConnectToAgilent():
    global N9010A
    if N9010A is None:
        rm = pyvisa.ResourceManager()
        N9010A = rm.open_resource(visa_agilent)
        N9010A.write(':INPut:COUPling %s' % ('AC'))
        N9010A.write(':SENSe:FREQuency:SPAN %G' % (4000000.0))
        N9010A.write(':SENSe:FREQuency:CENTer %G' % (250000000.0))
        N9010A.write(':FORMat:TRACe:DATA %s,%d' % ('REAL', 32))
        N9010A.write(':FORMat:BORDer %s' % ('SWAPped'))
        N9010A.write(':SENSe:OBWidth:FREQuency:SPAN %G' % (50000000.0))
        N9010A.write(':SENSe:CHPower:BANDwidth:INTegration %G' % (40000000.0))


def GetChPower():
    """
    Read the chanel power from the Agilent Technologies Signal Analyzer.

    Parameters: None

    Returns:
    - chanel power value. Type:
    """   
    chPower = N9010A.query_binary_values(':MEASure:CHPower:CHPower?','f',False)
    return chPower[0]

def GetBandWidth():
    """
    Read the occupied bandwidth from the Agilent Signal Analyzer.

    Parameters: None

    Returns:
    - occupied bandwidth.
    """   
    width = N9010A.query_binary_values(':READ:OBWidth?','f',False)
    return float(width[0])
