from rpi_stepper_motors import driver
from .functions import Manual, HalfManual, Automat, SearchingDataFromFile, Random
import sys

def run():
# %% Arguments
    if len(sys.argv) < 2:
        print("Usage: {} <mode> <step_divider> [<steps> <forward_span>]".format(sys.argv[0]))
        sys.exit(1)

    mode = sys.argv[1]

    if mode == 'manual':
        if len(sys.argv) != 3:
            print("Usage for manual mode: {} manual <step_divider>".format(sys.argv[0]))
            sys.exit(1)
        step_divider = int(sys.argv[2])
        print(f"Mode: {mode}, Step_Divider: {step_divider}")

    elif mode == 'halfmanual' or mode == 'automat':
        if not len(sys.argv) in (5, 6):
            print("Usage for halfmanual/automat mode: {} {} <step_divider> <steps> <forward_span> {{<diagnostics>}}".format(sys.argv[0], mode))
            sys.exit(1)
        step_divider = int(sys.argv[2])
        nsteps = int(sys.argv[3])
        forward_span = int(sys.argv[4])
        diagnostics = sys.argv[5] if len(sys.argv) == 6 else "menlo"
        print(f"Mode: {mode}, Step_Divider: {step_divider}, Steps: {nsteps}, Forward span: {forward_span}, Diagnostics: {diagnostics}")

    elif mode == 'readdata':
        if len(sys.argv) != 2:
            print("Usage for readdata mode: {} readdata".format(sys.argv[0]))
            sys.exit(1)
        print(f"Mode: {mode}")

    elif mode == 'random':
        if len(sys.argv) != 2:
            print("Usage for readdata mode: {} random".format(sys.argv[0]))
            sys.exit(1)
        print(f"Mode: {mode}")

    else:
        print("Invalid mode. Use 'manual', 'halfmanual', 'automat', 'readdata' or 'random'.")
        sys.exit(1)

# %% Initialize drivers
    driver.init_drivers()

# %% Enter mode
    if mode == 'manual':
        Manual(step_divider)
    elif mode == 'halfmanual':
        HalfManual(step_divider, nsteps, forward_span, diagnostics)
    elif mode == 'automat':
        Automat(step_divider, nsteps, forward_span, diagnostics)
    elif mode == 'readdata':
        SearchingDataFromFile()
    elif mode == 'random':
        Random()

if __name__ == '__main__':
    run()
