import keyboard
import time
import agilent
import menlo
from utils import CheckPreviousData
from driver import drivers, Driver

WSADKeys = ['w', 'a', 's', 'd', 'e', 'q', 'r', 'f']
MANUAL_HELP = 'First: Q - clockwise, A - counterclockwise \n Second: W - clockwise, S - counterclockwise \n Third: E - clockwise, D - counterclockwise \n Fourth: R - clockwise, F - counterclockwise.'
SWEEP_FILENAME = 'sweep_data.txt'


def looper(nsteps, forward_span):
    """Loop over all motors `forward_span` steps forward."""
    FirstDriver, SecondDriver, ThirdDriver, FourthDriver = drivers
    for i in range(forward_span):
        drivers.move(0, nsteps, 'clockwise')
        for j in range(forward_span):
            drivers.move(1, nsteps, 'clockwise')
            for k in range(forward_span):
                drivers.move(2, nsteps, 'clockwise')
                for l in range(forward_span):
                    drivers.move(3, nsteps, 'clockwise')
                    yield (i, j, k, l)


def Loop(step_divider, nsteps, forward_span, break_on_success=False):
    # TODO Jak radius nie jest podane, to poruszać się w całym zakresie.
    menlo.ConnectToMenlo()
    agilent.ConnectToAgilent()
    full_circle = Driver.steps_per_lap(step_divider)
    print('Number of steps in full circle:', full_circle)
    print('Number of steps per macrostep:', nsteps)
    print('Move each stepper motor +-macrosteps:', forward_span)
    drivers.set_step_sizes(step_divider)
    for (i, j, k, l) in looper(nsteps, forward_span):
        time.sleep(0.1)
        ac = menlo.GetAC()
        dc = menlo.GetDC()
        band = agilent.GetBandWidth()
        add_to_file = []
        add_to_file.extend(drivers.positions)
        add_to_file.extend([dc, ac, band])
        add_to_file = ' '.join([str(x) for x in add_to_file]) + '\n'
        with open(SWEEP_FILENAME, 'a') as f:
            f.write(add_to_file)
        if break_on_success and ac > 1200 and band < 1e6:
            print(f'Found AC: {ac}')
            return


def SearchingDataFromFile():
    print('Searching through data file. ')
    try: 
        combinations = CheckPreviousData('data.txt')
        for combination in combinations:
            print(combination)
            for i, pos in enumerate(combination):
                drivers.move_to_position(i, int(pos))
            print(f'\nSet to: {combination}. Press [p] to quit the manual part.')
            event = keyboard.read_event()  
            if event.event_type == keyboard.KEY_DOWN:  
                userInput = event.name

            if userInput in ['w', 'a', 's', 'd', 'e', 'q', 'r', 'f', 'p']:
                WSAD(userInput)

            if userInput == 'esc':
                break

        print('All done.')

    except KeyboardInterrupt:
        print("\nExiting the script.")

    finally:
        drivers.cleanup_pins()


def WSAD(event):
    if event == 'q':
        drivers.move(0, 1, 'clockwise')
    elif event == 'a':
        drivers.move(0, 1, 'counterclockwise')
    elif event == 'w':
        drivers.move(1, 1, 'clockwise')
    elif event == 's':
        drivers.move(1, 1, 'counterclockwise')
    elif event == 'e':
        drivers.move(2, 1, 'clockwise')
    elif event == 'd':
        drivers.move(2, 1, 'counterclockwise')
    elif event == 'r':
        drivers.move(3, 1, 'clockwise')
    elif event == 'f':
        drivers.move(3, 1, 'counterclockwise')
    elif event == 'p':
        return


def HalfManual(step_divider, nsteps, forward_span):
    print(MANUAL_HELP)
    print('Press [esc] to skip the manual control part. \n Press P to end the manual control.')
    drivers.set_step_sizes(step_divider)
    try:
        while True:
            Loop(step_divider, nsteps, forward_span, break_on_success=True)
            while True:
                event = keyboard.read_event()  
                if event.event_type == keyboard.KEY_DOWN:  
                    userInput = event.name
                    if userInput in WSADKeys:
                        WSAD(userInput)
                    if userInput == 'esc':
                        break
    except KeyboardInterrupt:
        print("\nExiting the script.")
    finally:
        drivers.cleanup_pins()


def Manual(step_divider):
    print(MANUAL_HELP)
    print('[CTR + C] to exit.')   
    drivers.set_step_sizes(step_divider)
    try:
        while True:
            event = keyboard.read_event()  
            if event.event_type == keyboard.KEY_DOWN:  
                userInput = event.name
                if userInput in WSADKeys:
                    WSAD(userInput, step_divider)
                if userInput == 'esc':
                    break
    except KeyboardInterrupt:
        print("\nExiting the script.")
    finally:
        drivers.cleanup_pins()


def Automat(step_divider, nsteps, forward_span):
    print('Saving data to file.')
    try:
        Loop(step_divider, nsteps, forward_span, break_on_success=False)
    except KeyboardInterrupt:
        print('\nExiting the script.')
    finally:
        drivers.cleanup_pins()


def Random():
    print('Go to random spot.')
    try:
        for i in range(4):
            drivers.move_to_random_position(i)
    finally:
        drivers.cleanup_pins()
