from driver import init_drivers
from functions import Manual, HalfManual, Automat, SearchingDataFromFile, Random
import sys

# %% Arguments
if len(sys.argv) < 2:
    print("Usage: {} <mode> <size> [<steps> <forward_span>]".format(sys.argv[0]))
    sys.exit(1)

mode = sys.argv[1]

if mode == 'manual':
    if len(sys.argv) != 3:
        print("Usage for manual mode: {} manual <size>".format(sys.argv[0]))
        sys.exit(1)
    size = sys.argv[2]
    print(f"Mode: {mode}, Size: {size}")

elif mode == 'halfmanual' or mode == 'automat':
    if len(sys.argv) != 5:
        print("Usage for halfmanual/automat mode: {} {} <size> <steps> <forward_span>".format(sys.argv[0], mode))
        sys.exit(1)
    size = sys.argv[2]
    nsteps = int(sys.argv[3])
    forward_span = int(sys.argv[4])
    print(f"Mode: {mode}, Size: {size}, Steps: {nsteps}, Forward span: {forward_span}")

elif mode == 'readdata':
    if len(sys.argv) != 2:
        print("Usage for readdata mode: {} readdata".format(sys.argv[0]))
        sys.exit(1)
    print(f"Mode: {mode}")

elif mode == 'random':
    if len(sys.argv) != 2:
        print("Usage for readdata mode: {} random".format(sys.argv[0]))
        sys.exit(1)
    print(f"Mode: {mode}")

else:
    print("Invalid mode. Use 'manual', 'halfmanual', 'automat', 'readdata' or 'random'.")
    sys.exit(1)

# %% Initialize drivers
init_drivers()

# %% Enter mode
if mode == 'manual':
    Manual(size)
elif mode == 'halfmanual':
    HalfManual(size, nsteps, forward_span)
elif mode == 'automat':
    Automat(size, nsteps, forward_span)
elif mode == 'readdata':
    SearchingDataFromFile()
elif mode == 'random':
    Random(size)
