from rpi_stepper_motors import driver
from .functions import Manual, Random, GoTo, MenloHalfManual
import sys

def run():
# %% Arguments
    if len(sys.argv) < 2:
        print("Usage: {} <mode> <step_divider> [<steps> <forward_span>]".format(sys.argv[0]))
        sys.exit(1)

    mode = sys.argv[1]

    if mode == 'manual':
        if len(sys.argv) != 3:
            print("Usage for manual mode: {} manual <step_divider>".format(sys.argv[0]))
            sys.exit(1)
        step_divider = int(sys.argv[2])
        print(f"Mode: {mode}, Step_Divider: {step_divider}")

    elif mode == 'automat':
        if len(sys.argv) not in (3,4):
            print("Usage for automat mode: {} {} <step_divider> {{<diagnostics>}}".format(sys.argv[0], mode))
            sys.exit(1)
        step_divider = int(sys.argv[2])
        diagnostics = sys.argv[3] if len(sys.argv) == 4 else "menlo"
        print(f"Mode: {mode}, Step_Divider: {step_divider}, Diagnostics: {diagnostics}")

    elif mode == 'random':
        if len(sys.argv) != 2:
            print("Usage for random mode: {} random".format(sys.argv[0]))
            sys.exit(1)
        print(f"Mode: {mode}")

    elif mode == 'goto':
        if len(sys.argv) != 7:
            print("Usage for goto mode: {} <step_divider> <first_position> <second_position> <third_position> <fourth_position>".format(sys.argv[0]))
            sys.exit(1)
        step_divider = int(sys.argv[2])
        combination = [int(sys.argv[3]), int(sys.argv[4]), int(sys.argv[5]), int(sys.argv[6])]
        print(f'Mode: {mode}. Setting positions: {combination}')

    else:
        print("Invalid mode. Use 'manual', 'automat', 'goto' or 'random'.")
        sys.exit(1)

# %% Initialize drivers
    driver.init_drivers()


# %% Enter mode
    if mode == 'manual':
        Manual(step_divider)
    elif mode == 'automat':
        MenloHalfManual(step_divider, diagnostics='menlo')
    elif mode == 'random':
        Random()
    elif mode == 'goto':
        GoTo(step_divider, combination)



if __name__ == '__main__':
    run()
